# yex

## What is it?

It's a TeX workalike in pure Python.

## Why?

Because.

(There will be a more serious readme here later.)

## Demo

As of 2022-03-19, this:
```
\def\TeX{T\kern-.1667em\lower.5ex\hbox{E}\kern-.125emX}
\shipout\hbox{This was set in Python by yex, not by \TeX.}
```

gives this:

![some typesetting](https://marnanel.org/stuff/yex-20220319.png)

## Links

* [SVG source for the above](https://marnanel.org/stuff/yex-20220319.svg))
* [Gitlab repository.](https://gitlab.com/marnanel/yex/) Please report lots of bugs.
* [Github mirror](https://github.com/marnanel/yex/), not always up to date.

Licenced under the GPL version 2.
